import path from "../../../shared/lib/isomorphic/path";
import * as Log from "../../../build/output/log";
function isStringOrURL(icon) {
    return typeof icon === "string" || icon instanceof URL;
}
function resolveUrl(url, metadataBase) {
    if (url instanceof URL) return url;
    if (!url) return null;
    try {
        // If we can construct a URL instance from url, ignore metadataBase
        const parsedUrl = new URL(url);
        return parsedUrl;
    } catch (_) {}
    if (!metadataBase) {
        if (process.env.NODE_ENV !== "production") {
            metadataBase = new URL(`http://localhost:${process.env.PORT || 3000}`);
            // Development mode warning
            Log.warn(`metadata.metadataBase is not set for resolving url "${url}", fallbacks to "${metadataBase.origin}". See https://beta.nextjs.org/docs/api-reference/metadata#metadatabase`);
        } else {
            throw new Error(`metadata.metadataBase needs to be set for resolving url "${url}". See https://beta.nextjs.org/docs/api-reference/metadata#metadatabase\n`);
        }
    }
    // Handle relative or absolute paths
    const basePath = metadataBase.pathname || "";
    const joinedPath = path.join(basePath, url);
    return new URL(joinedPath, metadataBase);
}
// Return a string url without trailing slash
const resolveStringUrl = (url)=>{
    const href = typeof url === "string" ? url : url.toString();
    return href.endsWith("/") ? href.slice(0, -1) : href;
};
export { isStringOrURL, resolveUrl, resolveStringUrl };

//# sourceMappingURL=resolve-url.js.map